@@ -5,10 +5,11 @@ import inspect
 from typing import Dict, List
 
 from .. import BaseExecutor
+from ...helper import typename
 
 
 class BaseCrafter(BaseExecutor):
-    """A :class:`BaseCrafter` transforms the content of `Document` or `Chunk`. It can be used for preprocessing,
+    """A :class:`BaseCrafter` transforms the content of `DocumentProto` or `Chunk`. It can be used for preprocessing,
     segmenting etc. It is an interface for Crafters which is a family of executors intended to apply
     transformations to single documents.
     The apply function is :func:`craft`, where the name of the arguments will be used as keys of the content.
@@ -18,7 +19,7 @@ class BaseCrafter(BaseExecutor):
         super().__init__(*args, **kwargs)
         self.required_keys = {k for k in inspect.getfullargspec(self.craft).args if k != 'self'}
         if not self.required_keys:
-            self.logger.warning(f'{self.__class__} works on keys, but no keys are specified')
+            self.logger.warning(f'{typename(self)} works on keys, but no keys are specified')
 
     def craft(self, *args, **kwargs) -> Dict:
         """The apply function of this executor.
