@@ -46,7 +46,10 @@ class BasePea(metaclass=PeaType):
         try:
             self.runtime = self._get_runtime_cls()(self.args)  # type: 'BaseRuntime'
         except Exception as ex:
-            self.logger.error(f'{ex!r} during {self.runtime_cls.__init__!r}', exc_info=self.args.show_exc_info)
+            self.logger.error(f'{ex!r} during {self.runtime_cls.__init__!r}' +
+                              f'add "--show-exc-info" to see the exception stack in details'
+                              if not self.args.show_exc_info else '',
+                              exc_info=self.args.show_exc_info)
             raise RuntimeFailToStart from ex
 
     def run(self):
@@ -63,7 +66,10 @@ class BasePea(metaclass=PeaType):
         try:
             self.runtime.setup()
         except Exception as ex:
-            self.logger.error(f'{ex!r} during {self.runtime.setup!r}', exc_info=self.args.show_exc_info)
+            self.logger.error(f'{ex!r} during {self.runtime.setup!r}' +
+                              f'add "--show-exc-info" to see the exception stack in details'
+                              if not self.args.show_exc_info else '',
+                              exc_info=self.args.show_exc_info)
         else:
             self.is_ready.set()
             try:
@@ -73,12 +79,18 @@ class BasePea(metaclass=PeaType):
             except KeyboardInterrupt:
                 self.logger.info(f'{self.runtime!r} is interrupted by user')
             except (Exception, SystemError) as ex:
-                self.logger.error(f'{ex!r} during {self.runtime.run_forever!r}', exc_info=self.args.show_exc_info)
+                self.logger.error(f'{ex!r} during {self.runtime.run_forever!r}' +
+                                  f'add "--show-exc-info" to see the exception stack in details'
+                                  if not self.args.show_exc_info else '',
+                                  exc_info=self.args.show_exc_info)
 
             try:
                 self.runtime.teardown()
             except Exception as ex:
-                self.logger.error(f'{ex!r} during {self.runtime.teardown!r}', exc_info=self.args.show_exc_info)
+                self.logger.error(f'{ex!r} during {self.runtime.teardown!r}' +
+                                  f'add "--show-exc-info" to see the exception stack in details'
+                                  if not self.args.show_exc_info else '',
+                                  exc_info=self.args.show_exc_info)
         finally:
             self.is_shutdown.set()
             self.is_ready.clear()
@@ -125,7 +137,10 @@ class BasePea(metaclass=PeaType):
                 self.runtime.cancel()
                 self.is_shutdown.wait()
             except Exception as ex:
-                self.logger.error(f'{ex!r} during {self.runtime.cancel!r}')
+                self.logger.error(f'{ex!r} during {self.runtime.cancel!r}' +
+                                  f'add "--show-exc-info" to see the exception stack in details'
+                                  if not self.args.show_exc_info else '',
+                                  exc_info=self.args.show_exc_info)
 
             # if it is not daemon, block until the process/thread finish work
             if not self.args.daemon:
